"use client";

import Image from "next/image";
import * as React from "react";

import useEmblaCarousel from "embla-carousel-react";
import { ArrowRight, MoveLeft } from "lucide-react";
import { useTranslations } from "next-intl";

import { Locale } from "@/i18n/routing";

import BlurFade from "../ui/blur-fade";
import AddToCart from "./add-to-cart-client";
import { ContentLines } from "./content-lines";

interface CarouselItem {
	id: number;
	oldPrice: string | number;
	newPrice: string | number;
	ProductName: string;
	image: string;
}

interface CarouselProps {
	items: CarouselItem[];
	title: string;
	subtitle?: string;
	lang: Locale;
	customSubTitle?: JSX.Element;
}

const ProductCarousel: React.FC<CarouselProps> = ({
	lang,
	items,
	title,
	subtitle,
	customSubTitle,
}) => {
	const [emblaRef, emblaApi] = useEmblaCarousel({
		align: "start",
		direction: lang === "ar" ? "rtl" : "ltr",
		// breakpoints: {
		//   "(min-width: 768px)": { slidesToScroll: 2 },
		//   "(min-width: 1024px)": { slidesToScroll: 3 },
		// },
	});

	const t = useTranslations("SimilarProducts");

	React.useEffect(() => {
		if (emblaApi) {
			emblaApi.reInit();
		}
	}, [emblaApi]);

	return (
		<section className="relative w-full overflow-hidden py-4">
			<div className="container relative mx-auto">
				{/* Carousel */}
				<div className="rounded-lg backdrop-blur-sm">
					{/* Navigation Arrows */}
					<div className="flex items-center justify-evenly px-2 lg:px-8">
						<button
							onClick={() => emblaApi?.scrollPrev()}
							className="mt-[34px] flex h-[41px] w-[41px] items-center justify-center rounded-full border-2 border-custom-primary-accent transition-all duration-300 hover:bg-white/30 lg:h-12 lg:w-12"
							aria-label="Previous slide"
						>
							<ArrowRight className="text-custom-primary-accent" />
						</button>
						{/* Header content */}
						<div className="flex flex-col items-center justify-center">
							<ContentLines
								title={title}
								underlineColor="custom-primary-accent"
								textColor="text-custom-primary-accent"
							/>
							{customSubTitle ? (
								customSubTitle
							) : (
								<p className="text-nowrap text-3xl leading-7 text-[#202020] md:text-4xl md:leading-10">
									{subtitle}
								</p>
							)}
						</div>
						<button
							onClick={() => emblaApi?.scrollNext()}
							className="mt-[34px] flex h-[41px] w-[41px] items-center justify-center rounded-full border-2 border-custom-primary-accent transition-all duration-300 hover:bg-white/30 lg:h-12 lg:w-12"
							aria-label="Next slide"
						>
							<MoveLeft className="text-custom-primary-accent" />
						</button>
					</div>

					<div className="mt-8 overflow-hidden" ref={emblaRef}>
						<div className="flex gap-8">
							{items?.map((item) => (
								<BlurFade
									direction="up"
									// delay={index * 0.5}
									duration={0.5}
									inView
									key={item.id}
									className="w-full min-w-0 flex-[0_0_calc(100%-16px)] sm:flex-[0_0_calc(50%-16px)] lg:flex-[0_0_calc(33.333%-16px)]"
								>
									<div
										className="w-full overflow-hidden rounded-lg bg-custom-background-third"
										style={{ border: "1px solid #DEDEDE", borderRadius: "9px" }}
									>
										<div className="relative h-[300px] w-full">
											<Image
												src={"/images/products/product-1.png"}
												alt="prouct image"
												fill
												style={{ objectFit: "cover" }}
											/>
										</div>

										<div className="flex flex-col items-center gap-4 p-6">
											{/* t("ProductName") */}
											<p className="text-lg">{item?.ProductName}</p>
											<div className="flex items-center gap-2">
												<p className="text-body font-bold text-custom-primary-accent">
													$ {item?.oldPrice}
												</p>
												<p className="text-sm font-bold text-[#606676] line-through">
													$ {item?.newPrice}
												</p>
											</div>
											{/* #2895c8 */}
											<AddToCart product_id={item.id} />
										</div>
									</div>
									{/* <div className="group relative overflow-hidden rounded-lg">
                    <Image
                      src={item.image}
                      alt={item.title}
                      width={392}
                      height={350}
                      className="h-full w-full rounded-lg object-cover"
                      style={{ height: "486px" }}
                    />
                    <div className="absolute bottom-0 left-0 right-0 flex flex-col items-center justify-center bg-[#1E1E1E]/85 p-6">
                      <h3 className="mb-2 font-bold text-white">{item.title}</h3>
                      <p className="mb-4 text-sm text-white/90">{item.description}</p>
                    </div>
                  </div> */}
								</BlurFade>
							))}
						</div>
					</div>
				</div>
			</div>
		</section>
	);
};

export default ProductCarousel;
